from .ac_controller import BroadlinkAcController
from .broadlink_controller import BroadlinkDeviceController
from .broadlink_rgb_lamp_controller import BroadlinkRgbLampController
from .tv_controller import BroadlinkTvController



from pysmarthome import Model, MultiCommandDeviceController
from ..managers.manager import BroadlinkManager
from base64 import b64decode as decode


class BroadlinkDeviceController(MultiCommandDeviceController):
    model_class = Model.extends(MultiCommandDeviceController.model_class, name='BroadlinkDevicesModel')
    manager_class = BroadlinkManager


    def send_command(self, id):
        for cmd in self.model.commands:
            if (cmd.label == id) or (cmd.id == id):
                return self.dev.send_data(decode(cmd.data))



from .broadlink_controller import BroadlinkDeviceController
from pysmarthome import Model, TvsModel, TvController, MultiCommandDevicesModel


class BroadlinkTvController(TvController, BroadlinkDeviceController):
    model_class = Model.extends(MultiCommandDevicesModel, TvsModel, name='BroadlinkTvsModel')


    def on(self):
        self.send_command('on')
        return True


    def off(self):
        self.send_command('off')
        return True


    def mute(self):
        self.send_command('mute')
        self.set_state(mute=not self.model.state.mute)


    def set_vol_by(self, n):
        self.set_int_state_attr_by('volume', n)


    def set_vol_to(self, target):
        self.set_int_state_attr_to('volume', target)



from .broadlink_controller import BroadlinkDeviceController
from pysmarthome import Model, AcsModel, AcController, MultiCommandDevicesModel


class BroadlinkAcController(AcController, BroadlinkDeviceController):
    model_class = Model.extends(MultiCommandDevicesModel, AcsModel, name='BroadlinkAcsModel')


    def on(self):
        self.send_command('on')
        return True


    def off(self):
        self.send_command('off')
        return True


    def set_temp_by(self, n):
        self.set_int_state_attr_by('temp', n)


    def set_temp_to(self, target):
        self.set_int_state_attr_to('temp', target)



from .managers import BroadlinkManager
from .controllers import BroadlinkAcController
from .controllers import BroadlinkTvController
from .controllers import BroadlinkDeviceController
from .controllers import BroadlinkRgbLampController

config = {
    'addr': { 'type': 'string', 'required': True }
}

device_controllers = [
    BroadlinkAcController,
    BroadlinkTvController,
    BroadlinkDeviceController,
    BroadlinkRgbLampController,
]


def on_load(**data):
    BroadlinkManager.init_client(**data)



from pysmarthome import Model, MultiCommandRgbLampController
from .broadlink_controller import BroadlinkDeviceController


class BroadlinkRgbLampController(BroadlinkDeviceController, MultiCommandRgbLampController):
    model_class = Model.extends(
        MultiCommandRgbLampController.model_class,
        name='BroadlinkMultiCommandRgbLampsModel'
    )



from setuptools import setup, find_packages

setup(
    name='pysmarthome-broadlink',
    description='Broadlink plugin for pysmarthome',
    version='1.2.2',
    author='Filipe Alves',
    author_email='filipe.alvesdefernando@gmail.com',
    install_requires=[
        'pysmarthome~=3.0',
        'broadlink',
    ],
    packages=find_packages(),
    url='https://github.com/filipealvesdef/pysmarthome-broadlink',
    zip_zafe=False,
)



import broadlink
from pysmarthome import Manager


class BroadlinkManager(Manager):
    @classmethod
    def init_client(cls, addr='', **config):
        print('Syncing with broadlink')
        i = cls.instance
        i.client = broadlink.discover(
            timeout=2,
            discover_ip_address=addr,
        )[0]
        i.client.auth()
        print('Auth!')


    def on_device_added(self, device):
        device.dev = self.client


    def send_data(self, data):
        self.client.send_data(data)
